@@ -6,7 +6,7 @@
 #include "config.h"
 #else
 #include <sys/locking.h>
-#define PACKAGE_NAME "ccache-swig.exe"
+#include "config_win32.h"
 #endif
 
 #include <stdio.h>
@@ -20,7 +20,9 @@
  #include <sys/wait.h>
  #include <sys/mman.h>
 #else
-#define _WIN32_WINNT 0x0500
+#ifndef _WIN32_WINNT
+ #define _WIN32_WINNT 0x0500
+#endif
  #include <windows.h>
  #include <shlobj.h>
 #endif
@@ -49,7 +51,7 @@
 #define STATUS_FATAL 4
 #define STATUS_NOCACHE 5
 
-#define MYNAME PACKAGE_NAME
+#define MYNAME PROGRAM_NAME
 
 #define LIMIT_MULTIPLE 0.8
 
@@ -159,7 +161,7 @@ int asprintf(char **ptr, const char *format, ...);
 int snprintf(char *,size_t ,const char *, ...);
 #endif
 
-void cleanup_dir(const char *dir, size_t maxfiles, size_t maxsize);
+void cleanup_dir(const char *dir, size_t maxfiles, size_t maxsize, size_t minfiles);
 void cleanup_all(const char *dir);
 void wipe_all(const char *dir);
 
@@ -200,6 +202,8 @@ typedef int (*COMPAR_FN_T)(const void *, const void *);
 
 /* mkstemp() on some versions of cygwin don't handle binary files, so
    override */
+/* Seems okay in Cygwin 1.7.0
 #ifdef __CYGWIN__
 #undef HAVE_MKSTEMP
 #endif
+*/
