@@ -6,12 +6,14 @@ chs = open("chapters").readlines()
 
 f = open("Contents.html","w")
 print >>f, """
-<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
 <HTML>
 <HEAD>
 <TITLE>SWIG Users Manual</TITLE>
+<meta http-equiv="content-type" content="text/html; charset=UTF-8">
 </HEAD>
 <BODY BGCOLOR="#ffffff">
+
 <H1><a name="Contents"></a>SWIG Users Manual</H1>
 
 <p>
