@@ -3,15 +3,15 @@
 	require "example.php";
 
 
-	$v = new_vector();
-        vector_x_set($v,1.0);
-        vector_y_set($v,2.0);
-        vector_z_set($v,3.0);
+	$v = new Vector();
+        $v->x = 1.0;
+        $v->y = 2.0;
+        $v->z = 3.0;
 
-	$w = new_vector();
-        vector_x_set($w,10.0);
-        vector_y_set($w,11.0);
-        vector_z_set($w,12.0);
+	$w = new Vector();
+        $w->x = 10.0;
+        $w->y = 11.0;
+        $w->z = 12.0;
 
 	echo "I just created the following vector\n";
 	vector_print($v);
@@ -25,7 +25,7 @@
 
 	echo "\nNow I'm going to add the vectors together\n";
 
-        $r = new_vector();
+        $r = new Vector();
 	vector_add($v, $w, $r);
 
 	vector_print($r);
