@@ -1,10 +1,10 @@
 from cpp17_u8_char_literals import *
 
-if cvar.a != 'a':
+if cvar.a != "a":
     raise RuntimeError
 
-if cvar.u != 'u':
+if cvar.u != "u":
     raise RuntimeError
 
-if cvar.u8 != '8':
+if cvar.u8 != "8":
     raise RuntimeError
