@@ -11,8 +11,8 @@ except:
     print d, "is not an instance"
     raise RuntimeError
 
-s = '%s' % d
-if str.find(s, 'ArithUnaryFunction') == -1:
+s = "%s" % d
+if str.find(s, "ArithUnaryFunction") == -1:
     print d, "is not an ArithUnaryFunction"
     raise RuntimeError
 
@@ -23,8 +23,8 @@ except:
     print e, "is not an instance"
     raise RuntimeError
 
-s = '%s' % e
-if str.find(s, 'ArithUnaryFunction') == -1:
+s = "%s" % e
+if str.find(s, "ArithUnaryFunction") == -1:
     print e, "is not an ArithUnaryFunction"
     raise RuntimeError
 
@@ -40,8 +40,8 @@ except:
     print c, "is not an instance"
     raise RuntimeError
 
-s = '%s' % c
-if str.find(s, 'ArithUnaryFunction') == -1:
+s = "%s" % c
+if str.find(s, "ArithUnaryFunction") == -1:
     print c, "is not an ArithUnaryFunction"
     raise RuntimeError
 
@@ -52,8 +52,8 @@ except:
     print f, "is not an instance"
     raise RuntimeError
 
-s = '%s' % f
-if str.find(s, 'ArithUnaryFunction') == -1:
+s = "%s" % f
+if str.find(s, "ArithUnaryFunction") == -1:
     print f, "is not an ArithUnaryFunction"
     raise RuntimeError
 
@@ -68,8 +68,8 @@ except:
     print g, "is not an instance"
     raise RuntimeError
 
-s = '%s' % g
-if str.find(s, 'ArithUnaryFunction') == -1:
+s = "%s" % g
+if str.find(s, "ArithUnaryFunction") == -1:
     print g, "is not an ArithUnaryFunction"
     raise RuntimeError
 
@@ -81,7 +81,7 @@ except:
     print h, "is not an instance"
     raise RuntimeError
 
-s = '%s' % h
-if str.find(s, 'ArithUnaryFunction') == -1:
+s = "%s" % h
+if str.find(s, "ArithUnaryFunction") == -1:
     print h, "is not an ArithUnaryFunction"
     raise RuntimeError
