@@ -1,8 +1,10 @@
 
-namespace SwigExamples {
-
 # if defined(_WIN32) || defined(__WIN32__)
 
+#include <windows.h>
+
+namespace SwigExamples {
+
 class CriticalSection {
 public:
   CriticalSection() {
@@ -25,13 +27,23 @@ private:
   CriticalSection &critical_section;
 };
 
+}
+
 #else
 
 #include <pthread.h>
+#ifndef PTHREAD_MUTEX_RECURSIVE_NP
+  // For Cygwin and possibly other OSs: _NP is "non-portable"
+  #define PTHREAD_MUTEX_RECURSIVE_NP PTHREAD_MUTEX_RECURSIVE
+#endif
+
+namespace SwigExamples {
+
 class CriticalSection {
 public:
   CriticalSection() {
     pthread_mutexattr_t mutexattr;
+    pthread_mutexattr_init(&mutexattr);
     pthread_mutexattr_settype(&mutexattr, PTHREAD_MUTEX_RECURSIVE_NP);
     pthread_mutex_init(&mutex_, &mutexattr);
     pthread_mutexattr_destroy(&mutexattr);
@@ -53,7 +65,7 @@ private:
   CriticalSection &critical_section;
 };
 
-#endif
-
 }
 
+#endif
+
