@@ -23,6 +23,7 @@
 #include "swigwarn.h"
 #include "cparse.h"
 #include <ctype.h>
+#include <errno.h>
 #include <limits.h>		// for INT_MAX
 
 // Global variables
@@ -38,14 +39,15 @@ int NoExcept = 0;
 int SwigRuntime = 0;		// 0 = no option, 1 = -runtime, 2 = -noruntime
 
 /* Suppress warning messages for private inheritance, preprocessor evaluation etc...
-   WARN_PP_EVALUATION            202
-   WARN_PARSE_PRIVATE_INHERIT    309
-   WARN_TYPE_ABSTRACT            403
-   WARN_LANG_OVERLOAD_CONST      512
-   WARN_PARSE_BUILTIN_NAME       321
-   WARN_PARSE_REDUNDANT          322
+   WARN_PP_EVALUATION                           202
+   WARN_PARSE_PRIVATE_INHERIT                   309
+   WARN_PARSE_BUILTIN_NAME                      321
+   WARN_PARSE_REDUNDANT                         322
+   WARN_TYPE_ABSTRACT                           403
+   WARN_TYPE_RVALUE_REF_QUALIFIER_IGNORED       405
+   WARN_LANG_OVERLOAD_CONST                     512
  */
-#define EXTRA_WARNINGS "202,309,403,512,321,322"
+#define EXTRA_WARNINGS "202,309,403,405,512,321,322"
 
 extern "C" {
   extern String *ModuleName;
@@ -64,7 +66,7 @@ static const char *usage1 = (const char *) "\
      -copyctor       - Automatically generate copy constructors wherever possible\n\
      -cpperraswarn   - Treat the preprocessor #error statement as #warning (default)\n\
      -cppext <ext>   - Change file extension of generated C++ files to <ext>\n\
-                       (default is cxx, except for PHP which uses cpp)\n\
+                       (default is cxx)\n\
      -copyright      - Display copyright notices\n\
      -debug-classes  - Display information about the classes found in the interface\n\
      -debug-module <n>- Display module parse tree at stages 1-4, <n> is a csv list of stages\n\
@@ -96,7 +98,7 @@ static const char *usage2 = (const char *) "\
      -Fmicrosoft     - Display error/warning messages in Microsoft format\n\
      -Fstandard      - Display error/warning messages in commonly used format\n\
      -fvirtual       - Compile in virtual elimination mode\n\
-     -help           - This output\n\
+     -help           - Display help\n\
      -I-             - Don't search the current directory\n\
      -I<dir>         - Look for SWIG files in directory <dir>\n\
      -ignoremissing  - Ignore missing include files\n\
@@ -129,14 +131,14 @@ static const char *usage3 = (const char *) "\
 ";
 
 static const char *usage4 = (const char *) "\
-     -O              - Enable the optimization options: \n\
-                        -fastdispatch -fvirtual \n\
+     -O              - Enable the optimization options:\n\
+                        -fastdispatch -fvirtual\n\
      -o <outfile>    - Set name of C/C++ output file to <outfile>\n\
      -oh <headfile>  - Set name of C++ output header file for directors to <headfile>\n\
      -outcurrentdir  - Set default output dir to current dir instead of input file's path\n\
      -outdir <dir>   - Set language specific files output directory to <dir>\n\
      -pcreversion    - Display PCRE version information\n\
-     -small          - Compile in virtual elimination & compact mode\n\
+     -small          - Compile in virtual elimination and compact mode\n\
      -swiglib        - Report location of SWIG library and exit\n\
      -templatereduce - Reduce all the typedefs in templates\n\
      -v              - Run in verbose mode\n\
@@ -154,10 +156,14 @@ Options can also be defined using the SWIG_FEATURES environment variable, for ex
   $ export SWIG_FEATURES\n\
   $ swig -python interface.i\n\
 \n\
-is equivalent to: \n\
+is equivalent to:\n\
 \n\
-  $ swig -Wall -python interface.i \n\
+  $ swig -Wall -python interface.i\n\
 \n\
+Arguments may also be passed in a file, separated by whitespace. For example:\n\
+\n\
+  $ echo \"-Wall -python interface.i\" > args.txt\n\
+  $ swig @args.txt\n\
 \n";
 
 // Local variables
@@ -454,7 +460,7 @@ static void SWIG_dump_runtime() {
   SWIG_exit(EXIT_SUCCESS);
 }
 
-void SWIG_getoptions(int argc, char *argv[]) {
+static void getoptions(int argc, char *argv[]) {
   int i;
   // Get options
   for (i = 1; i < argc; i++) {
@@ -873,7 +879,7 @@ void SWIG_getoptions(int argc, char *argv[]) {
   }
 }
 
-int SWIG_main(int argc, char *argv[], Language *l) {
+int SWIG_main(int argc, char *argv[], const TargetLanguageModule *tlm) {
   char *c;
 
   /* Initialize the SWIG core */
@@ -885,7 +891,9 @@ int SWIG_main(int argc, char *argv[], Language *l) {
   // Initialize the preprocessor
   Preprocessor_init();
 
-  lang = l;
+  // Set lang to a dummy value if no target language was specified so we
+  // can process options enough to handle -version, etc.
+  lang = tlm ? tlm->fac() : new Language;
 
   // Set up some default symbols (available in both SWIG interface files
   // and C files)
@@ -918,9 +926,9 @@ int SWIG_main(int argc, char *argv[], Language *l) {
   Wrapper_director_protected_mode_set(1);
 
   // Inform the parser if the nested classes should be ignored unless explicitly told otherwise via feature:flatnested
-  ignore_nested_classes = l->nestedClassesSupport() == Language::NCS_Unknown ? 1 : 0;
+  ignore_nested_classes = lang->nestedClassesSupport() == Language::NCS_Unknown ? 1 : 0;
 
-  kwargs_supported = l->kwargsSupport() ? 1 : 0;
+  kwargs_supported = lang->kwargsSupport() ? 1 : 0;
 
   // Create Library search directories
 
@@ -949,7 +957,7 @@ int SWIG_main(int argc, char *argv[], Language *l) {
 
   /* Check for SWIG_FEATURES environment variable */
 
-  SWIG_getoptions(argc, argv);
+  getoptions(argc, argv);
 
   // Define the __cplusplus symbol
   if (CPlusPlus)
@@ -962,6 +970,7 @@ int SWIG_main(int argc, char *argv[], Language *l) {
     Printf(stdout, "\nNote: 'swig -<lang> -help' displays options for a specific target language.\n\n");
     SWIG_exit(EXIT_SUCCESS);	// Exit if we're in help mode
   }
+
   // Check all of the options to make sure we're cool.
   // Don't check for an input file if -external-runtime is passed
   Swig_check_options(external_runtime ? 0 : 1);
@@ -1057,7 +1066,7 @@ int SWIG_main(int argc, char *argv[], Language *l) {
 	  char *cfile = Char(input_file);
 	  if (cfile && cfile[0] == '-') {
 	    Printf(stderr, "Unable to find option or file '%s', ", input_file);
-	    Printf(stderr, "use 'swig -help' for more information.\n");
+	    Printf(stderr, "Use 'swig -help' for more information.\n");
 	  } else {
 	    Printf(stderr, "Unable to find file '%s'.\n", input_file);
 	  }
@@ -1066,6 +1075,13 @@ int SWIG_main(int argc, char *argv[], Language *l) {
 	  Swig_warning(WARN_DEPRECATED_INPUT_FILE, "SWIG", 1, "Use of the include path to find the input file is deprecated and will not work with ccache. Please include the path when specifying the input file.\n"); // so that behaviour is like c/c++ compilers
 	}
       }
+
+      if (!tlm) {
+	Printf(stderr, "No target language specified.\n");
+	Printf(stderr, "Use 'swig -help' for more information.\n");
+	SWIG_exit(EXIT_FAILURE);
+      }
+
       if (!no_cpp) {
 	fclose(df);
 	Printf(fs, "%%include <swig.swg>\n");
@@ -1300,6 +1316,13 @@ int SWIG_main(int argc, char *argv[], Language *l) {
 	// Check the extension for a c/c++ file.  If so, we're going to declare everything we see as "extern"
 	ForceExtern = check_extension(input_file);
 
+	if (tlm->status == Experimental) {
+	  Swig_warning(WARN_LANG_EXPERIMENTAL, "SWIG", 1, "Experimental target language. "
+	    "Target language %s specified by %s is an experimental language. "
+	    "Please read about SWIG experimental languages, http://swig.org/Doc4.0/Introduction.html#Introduction_experimental_status.\n",
+	    tlm->help ? tlm->help : "", tlm->name);
+	}
+
 	lang->top(top);
 
 	if (browse) {
@@ -1354,13 +1377,15 @@ int SWIG_main(int argc, char *argv[], Language *l) {
   while (freeze) {
   }
 
-  if ((werror) && (Swig_warn_count())) {
-    return Swig_warn_count();
-  }
-
   delete lang;
 
-  return Swig_error_count();
+  int error_count = werror ? Swig_warn_count() : 0;
+  error_count += Swig_error_count();
+
+  if (error_count != 0)
+    SWIG_exit(error_count);
+
+  return 0;
 }
 
 /* -----------------------------------------------------------------------------
@@ -1372,5 +1397,20 @@ int SWIG_main(int argc, char *argv[], Language *l) {
 void SWIG_exit(int exit_code) {
   while (freeze) {
   }
+
+  if (exit_code > 0) {
+    CloseAllOpenFiles();
+
+    /* Remove all generated files */
+    if (all_output_files) {
+      for (int i = 0; i < Len(all_output_files); i++) {
+	String *filename = Getitem(all_output_files, i);
+	int removed = remove(Char(filename));
+	if (removed == -1)
+	  fprintf(stderr, "On exit, could not delete file %s: %s\n", Char(filename), strerror(errno));
+      }
+    }
+  }
+
   exit(exit_code);
 }
